### Changelog

All notable changes to this project will be documented in this file. Dates are displayed in UTC.

Generated by [`auto-changelog`](https://github.com/CookPete/auto-changelog).

#### [0.2.0](https://github.com/hemna/aprsd-rich-cli-extension/compare/0.1.1...0.2.0)

> 27 October 2025

- move deps into pyproject.toml [`9e6c323`](https://github.com/hemna/aprsd-rich-cli-extension/commit/9e6c323bd1bf64caeb3d7b67b57fddd34be3216c)

#### [0.1.1](https://github.com/hemna/aprsd-rich-cli-extension/compare/0.1.0...0.1.1)

> 12 October 2025

- stop all [`3d0867a`](https://github.com/hemna/aprsd-rich-cli-extension/commit/3d0867ad3083f9d7235c8b11db82074c7c9ecb25)

#### [0.1.0](https://github.com/hemna/aprsd-rich-cli-extension/compare/v0.1.0...0.1.0)

> 12 August 2025

- First version of listen working! [`80e24c4`](https://github.com/hemna/aprsd-rich-cli-extension/commit/80e24c4e7f0bdfd194f388939bebe81000a1f10b)
- CHAT! First version of chat mostly working. [`97fe001`](https://github.com/hemna/aprsd-rich-cli-extension/commit/97fe001178a35660939b914cca1d903c1a6ced97)
- Added keybindings to tabs [`25ae877`](https://github.com/hemna/aprsd-rich-cli-extension/commit/25ae8777dd777a849eb61f97677d581d121cf27d)
- Add tab when message from new callsign. [`3359a03`](https://github.com/hemna/aprsd-rich-cli-extension/commit/3359a03d0ab98cdd0c41a416cd966dd8be91c9a5)
- Got acks working and beacons [`e9325c8`](https://github.com/hemna/aprsd-rich-cli-extension/commit/e9325c827ed4ec96d2365aa73c7ed6e3c9be7ee7)
- update requirements from 4.1.1 [`4590322`](https://github.com/hemna/aprsd-rich-cli-extension/commit/4590322eb7d908b682839cc3dbbe9150759a9036)
- Got Log tab working. [`d3ffcff`](https://github.com/hemna/aprsd-rich-cli-extension/commit/d3ffcff5a41aed1264b865aa627a836f479ccdf7)
- Got working with newest aprsd [`c956c49`](https://github.com/hemna/aprsd-rich-cli-extension/commit/c956c49093ced3440dce59f3f3c16e50f1f2bd0d)
- more of the reworked app working. [`40eb4d3`](https://github.com/hemna/aprsd-rich-cli-extension/commit/40eb4d37be6a15fc4ff41600b35731d82903a7e2)
- Updated pyproject for ruff [`ea6cab5`](https://github.com/hemna/aprsd-rich-cli-extension/commit/ea6cab53407de21856ab81394a43515fc0f34b1c)
- update content type for readme [`f47c6ab`](https://github.com/hemna/aprsd-rich-cli-extension/commit/f47c6ab696f50aee9e0974b51e8e4ef7d0ac8e3c)

#### v0.1.0

> 24 February 2025

- Initial commit [`897e42b`](https://github.com/hemna/aprsd-rich-cli-extension/commit/897e42b47ba5bb76d303e62c7e026654fdd6b136)
